Dask Kubernetes
===============

|Build Status|

Native Kubernetes integration for Dask.

See documentation for more information:
`kubernetes.dask.org <https://kubernetes.dask.org/en/latest>`_

.. |Build Status| image:: https://circleci.com/gh/dask/dask-kubernetes.svg?&style=shield
   :target: https://circleci.com/gh/dask/dask-kubernetes
